@@ -12,7 +12,8 @@ import logging
 # control
 import os
 import sys
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple
+from typing import TYPE_CHECKING, Any, Collection, Dict, List, Optional
+import warnings
 
 import click
 
@@ -111,22 +112,6 @@ def generate_metadata(
     return xmltodict.unparse(codemetadata, pretty=True)
 
 
-def _client(url: str, username: str, password: str) -> PublicApiDepositClient:
-    """Instantiate a client to access the deposit api server
-
-    Args:
-        url (str): Deposit api server
-        username (str): User
-        password (str): User's password
-
-    """
-    from swh.deposit.client import PublicApiDepositClient
-
-    return PublicApiDepositClient(
-        {"url": url, "auth": {"username": username, "password": password},}
-    )
-
-
 def _collection(client: PublicApiDepositClient) -> str:
     """Retrieve the client's collection
 
@@ -140,12 +125,10 @@ def _collection(client: PublicApiDepositClient) -> str:
 
 
 def client_command_parse_input(
+    client,
     username: str,
-    password: str,
     archive: Optional[str],
     metadata: Optional[str],
-    archive_deposit: bool,
-    metadata_deposit: bool,
     collection: Optional[str],
     slug: Optional[str],
     partial: bool,
@@ -187,34 +170,22 @@ def client_command_parse_input(
     Returns:
         dict with the following keys:
 
-            'archive': the software archive to deposit
-            'username': username
-            'password': associated password
-            'metadata': the metadata file to deposit
-            'collection': the username's associated client
-            'slug': the slug or external id identifying the deposit to make
-            'partial': if the deposit is partial or not
-            'client': instantiated class
-            'url': deposit's server main entry point
-            'deposit_type': deposit's type (binary, multipart, metadata)
-            'deposit_id': optional deposit identifier
-            'swhid': optional deposit swhid
-
+            "archive": the software archive to deposit
+            "username": username
+            "metadata": the metadata file to deposit
+            "collection": the user's collection under which to put the deposit
+            "slug": the slug or external id identifying the deposit to make
+            "in_progress": if the deposit is partial or not
+            "url": deposit's server main entry point
+            "deposit_id": optional deposit identifier
+            "swhid": optional deposit swhid
+            "replace": whether the given deposit is to be replaced or not
     """
-    if archive_deposit and metadata_deposit:
-        # too many flags use, remove redundant ones (-> multipart deposit)
-        archive_deposit = False
-        metadata_deposit = False
 
     if not slug:  # generate one as this is mandatory
         slug = generate_slug()
 
     if not metadata:
-        if metadata_deposit:
-            raise InputError(
-                "Metadata deposit must be provided for metadata "
-                "deposit, either a filepath with --metadata or --name and --author"
-            )
         if name and authors:
             metadata_path = os.path.join(temp_dir, "metadata.xml")
             logging.debug("Temporary file: %s", metadata_path)
@@ -223,7 +194,7 @@ def client_command_parse_input(
             with open(metadata_path, "w") as f:
                 f.write(metadata_xml)
             metadata = metadata_path
-        elif not archive_deposit and not partial and not deposit_id:
+        elif archive is not None and not partial and not deposit_id:
             # If we meet all the following conditions:
             # * this is not an archive-only deposit request
             # * it is not part of a multipart deposit (either create/update
@@ -232,7 +203,6 @@ def client_command_parse_input(
             raise InputError(
                 "For metadata deposit request, either a metadata file with "
                 "--metadata or both --author and --name must be provided. "
-                "If this is an archive deposit request, none is required."
             )
         elif name or authors:
             # If we are generating metadata, then all mandatory metadata
@@ -251,13 +221,7 @@ def client_command_parse_input(
             "--author and --name (Those are used to generate one metadata file)."
         )
 
-    if metadata_deposit:
-        archive = None
-
-    if archive_deposit:
-        metadata = None
-
-    if not archive and not metadata and partial:
+    if not archive and not metadata:
         raise InputError(
             "Please provide an actionable command. See --help for more information"
         )
@@ -265,20 +229,16 @@ def client_command_parse_input(
     if replace and not deposit_id:
         raise InputError("To update an existing deposit, you must provide its id")
 
-    client = _client(url, username, password)
-
     if not collection:
         collection = _collection(client)
 
     return {
         "archive": archive,
         "username": username,
-        "password": password,
         "metadata": metadata,
         "collection": collection,
         "slug": slug,
         "in_progress": partial,
-        "client": client,
         "url": url,
         "deposit_id": deposit_id,
         "swhid": swhid,
@@ -286,42 +246,11 @@ def client_command_parse_input(
     }
 
 
-def _subdict(d: Dict[str, Any], keys: Tuple[str, ...]) -> Dict[str, Any]:
+def _subdict(d: Dict[str, Any], keys: Collection[str]) -> Dict[str, Any]:
     "return a dict from d with only given keys"
     return {k: v for k, v in d.items() if k in keys}
 
 
-def deposit_create(config: Dict[str, Any]) -> Dict[str, Any]:
-    """Delegate the actual deposit to the deposit client.
-
-    """
-    logger.debug("Create deposit")
-
-    client = config["client"]
-    keys = ("collection", "archive", "metadata", "slug", "in_progress")
-    return client.deposit_create(**_subdict(config, keys))
-
-
-def deposit_update(config: Dict[str, Any]) -> Dict[str, Any]:
-    """Delegate the actual deposit to the deposit client.
-
-    """
-    logger.debug("Update deposit")
-
-    client = config["client"]
-    keys = (
-        "collection",
-        "deposit_id",
-        "archive",
-        "metadata",
-        "slug",
-        "in_progress",
-        "replace",
-        "swhid",
-    )
-    return client.deposit_update(**_subdict(config, keys))
-
-
 @deposit.command()
 @click.option("--username", required=True, help="(Mandatory) User's name")
 @click.option(
@@ -343,12 +272,12 @@ def deposit_update(config: Dict[str, Any]) -> Dict[str, Any]:
 @click.option(
     "--archive-deposit/--no-archive-deposit",
     default=False,
-    help="(Optional) Software archive only deposit",
+    help="Deprecated (ignored)",
 )
 @click.option(
     "--metadata-deposit/--no-metadata-deposit",
     default=False,
-    help="(Optional) Metadata only deposit",
+    help="Deprecated (ignored)",
 )
 @click.option(
     "--collection",
@@ -413,21 +342,21 @@ def upload(
     ctx,
     username: str,
     password: str,
-    archive: Optional[str] = None,
-    metadata: Optional[str] = None,
-    archive_deposit: bool = False,
-    metadata_deposit: bool = False,
-    collection: Optional[str] = None,
-    slug: Optional[str] = None,
-    partial: bool = False,
-    deposit_id: Optional[int] = None,
-    swhid: Optional[str] = None,
-    replace: bool = False,
-    url: str = "https://deposit.softwareheritage.org",
-    verbose: bool = False,
-    name: Optional[str] = None,
-    author: List[str] = [],
-    output_format: Optional[str] = None,
+    archive: Optional[str],
+    metadata: Optional[str],
+    archive_deposit: bool,
+    metadata_deposit: bool,
+    collection: Optional[str],
+    slug: Optional[str],
+    partial: bool,
+    deposit_id: Optional[int],
+    swhid: Optional[str],
+    replace: bool,
+    url: str,
+    verbose: bool,
+    name: Optional[str],
+    author: List[str],
+    output_format: Optional[str],
 ):
     """Software Heritage Public Deposit Client
 
@@ -439,21 +368,28 @@ https://docs.softwareheritage.org/devel/swh-deposit/getting-started.html.
     """
     import tempfile
 
-    from swh.deposit.client import MaintenanceError
+    from swh.deposit.client import MaintenanceError, PublicApiDepositClient
+
+    if archive_deposit or metadata_deposit:
+        warnings.warn(
+            '"archive_deposit" and "metadata_deposit" option arguments are '
+            "deprecated and have no effect; simply do not provide the archive "
+            "for a metadata-only deposit, and do not provide a metadata for a"
+            "archive-only deposit.",
+            DeprecationWarning,
+        )
 
     url = _url(url)
-    config = {}
 
+    client = PublicApiDepositClient(url=url, auth=(username, password))
     with tempfile.TemporaryDirectory() as temp_dir:
         try:
             logger.debug("Parsing cli options")
             config = client_command_parse_input(
+                client,
                 username,
-                password,
                 archive,
                 metadata,
-                archive_deposit,
-                metadata_deposit,
                 collection,
                 slug,
                 partial,
@@ -475,12 +411,13 @@ https://docs.softwareheritage.org/devel/swh-deposit/getting-started.html.
         if verbose:
             logger.info("Parsed configuration: %s", config)
 
-        deposit_id = config["deposit_id"]
-
-        if deposit_id:
-            data = deposit_update(config)
+        keys = ["archive", "collection", "in_progress", "metadata", "slug"]
+        if config["deposit_id"]:
+            keys += ["deposit_id", "replace", "swhid"]
+            data = client.deposit_update(**_subdict(config, keys))
         else:
-            data = deposit_create(config)
+            data = client.deposit_create(**_subdict(config, keys))
+
         print_result(data, output_format)
 
 
@@ -509,12 +446,12 @@ def status(ctx, url, username, password, deposit_id, output_format):
     """Deposit's status
 
     """
-    from swh.deposit.client import MaintenanceError
+    from swh.deposit.client import MaintenanceError, PublicApiDepositClient
 
     url = _url(url)
     logger.debug("Status deposit")
     try:
-        client = _client(url, username, password)
+        client = PublicApiDepositClient(url=url, auth=(username, password))
         collection = _collection(client)
     except InputError as e:
         logger.error("Problem during parsing options: %s", e)
