@@ -4,39 +4,26 @@
 # See top-level LICENSE file for more information
 
 import logging
+from typing import Any, Dict
 
-from typing import Mapping
-
-from swh.core.config import SWHConfig
-
+from swh.core import config
 from swh.deposit.client import PrivateApiDepositClient
 
-
 logger = logging.getLogger(__name__)
 
 
-class DepositChecker(SWHConfig):
+class DepositChecker:
     """Deposit checker implementation.
 
     Trigger deposit's checks through the private api.
 
     """
 
-    CONFIG_BASE_FILENAME = "deposit/checker"
-
-    DEFAULT_CONFIG = {
-        "deposit": ("dict", {"url": "http://localhost:5006/1/private/", "auth": {},})
-    }
-
-    def __init__(self, config=None):
-        super().__init__()
-        if config is None:
-            self.config = self.parse_config_file()
-        else:
-            self.config = config
+    def __init__(self):
+        self.config: Dict[str, Any] = config.load_from_envvar()
         self.client = PrivateApiDepositClient(config=self.config["deposit"])
 
-    def check(self, collection: str, deposit_id: str) -> Mapping[str, str]:
+    def check(self, collection: str, deposit_id: str) -> Dict[str, str]:
         status = None
         deposit_check_url = f"/{collection}/{deposit_id}/check/"
         logger.debug("deposit-check-url: %s", deposit_check_url)
