@@ -3,22 +3,17 @@
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
-import pytest
+from io import BytesIO
 
 from django.core.files.uploadedfile import InMemoryUploadedFile
 from django.urls import reverse
-from io import BytesIO
-
+import pytest
 from rest_framework import status
 
-from swh.deposit.config import (
-    COL_IRI,
-    EM_IRI,
-    DEPOSIT_STATUS_DEPOSITED,
-)
+from swh.deposit.config import COL_IRI, DEPOSIT_STATUS_DEPOSITED, EM_IRI
 from swh.deposit.models import Deposit, DepositRequest
 from swh.deposit.parsers import parse_xml
-from swh.deposit.tests.common import create_arborescence_archive, check_archive
+from swh.deposit.tests.common import check_archive, create_arborescence_archive
 
 
 def test_post_deposit_binary_no_slug(
@@ -113,7 +108,7 @@ def test_post_deposit_binary_upload_ok(
     assert deposit.status == DEPOSIT_STATUS_DEPOSITED
     assert deposit.external_id == external_id
     assert deposit.collection == deposit_collection
-    assert deposit.swh_id is None
+    assert deposit.swhid is None
 
     deposit_request = DepositRequest.objects.get(deposit=deposit)
     check_archive(sample_archive["name"], deposit_request.archive.name)
@@ -160,6 +155,11 @@ def test_post_deposit_binary_failure_unsupported_packaging_header(
 
     # then
     assert response.status_code == status.HTTP_400_BAD_REQUEST
+    assert (
+        b"The packaging provided something-unsupported is not supported"
+        in response.content
+    )
+
     with pytest.raises(Deposit.DoesNotExist):
         Deposit.objects.get(external_id=external_id)
 
@@ -190,6 +190,8 @@ def test_post_deposit_binary_upload_no_content_disposition_header(
 
     # then
     assert response.status_code == status.HTTP_400_BAD_REQUEST
+    assert b"CONTENT_DISPOSITION header is mandatory" in response.content
+
     with pytest.raises(Deposit.DoesNotExist):
         Deposit.objects.get(external_id=external_id)
 
@@ -361,7 +363,7 @@ def test_post_deposit_binary_and_post_to_add_another_archive(
     assert deposit.status == "partial"
     assert deposit.external_id == external_id
     assert deposit.collection == deposit_collection
-    assert deposit.swh_id is None
+    assert deposit.swhid is None
 
     deposit_request = DepositRequest.objects.get(deposit=deposit)
     assert deposit_request.deposit == deposit
@@ -396,7 +398,7 @@ def test_post_deposit_binary_and_post_to_add_another_archive(
     assert deposit.status == DEPOSIT_STATUS_DEPOSITED
     assert deposit.external_id == external_id
     assert deposit.collection == deposit_collection
-    assert deposit.swh_id is None
+    assert deposit.swhid is None
 
     deposit_requests = list(
         DepositRequest.objects.filter(deposit=deposit).order_by("id")
@@ -452,7 +454,7 @@ def test_post_deposit_then_update_refused(
     assert deposit.status == DEPOSIT_STATUS_DEPOSITED
     assert deposit.external_id == external_id
     assert deposit.collection == deposit_collection
-    assert deposit.swh_id is None
+    assert deposit.swhid is None
 
     deposit_request = DepositRequest.objects.get(deposit=deposit)
     assert deposit_request.deposit == deposit
@@ -486,6 +488,7 @@ def test_post_deposit_then_update_refused(
     )
 
     assert r.status_code == status.HTTP_400_BAD_REQUEST
+    assert b"You can only act on deposit with status &#39;partial&#39;" in r.content
 
     # adding file is no longer possible since the deposit's status
     # is ready
@@ -502,6 +505,7 @@ def test_post_deposit_then_update_refused(
     )
 
     assert r.status_code == status.HTTP_400_BAD_REQUEST
+    assert b"You can only act on deposit with status &#39;partial&#39;" in r.content
 
     # replacing metadata is no longer possible since the deposit's
     # status is ready
@@ -514,6 +518,7 @@ def test_post_deposit_then_update_refused(
     )
 
     assert r.status_code == status.HTTP_400_BAD_REQUEST
+    assert b"You can only act on deposit with status &#39;partial&#39;" in r.content
 
     # adding new metadata is no longer possible since the
     # deposit's status is ready
@@ -526,6 +531,7 @@ def test_post_deposit_then_update_refused(
     )
 
     assert r.status_code == status.HTTP_400_BAD_REQUEST
+    assert b"You can only act on deposit with status &#39;partial&#39;" in r.content
 
     archive_content = b"some content representing archive"
     archive = InMemoryUploadedFile(
@@ -555,6 +561,7 @@ def test_post_deposit_then_update_refused(
     )
 
     assert r.status_code == status.HTTP_400_BAD_REQUEST
+    assert b"You can only act on deposit with status &#39;partial&#39;" in r.content
 
     # adding new metadata is no longer possible since the
     # deposit's status is ready
@@ -565,3 +572,4 @@ def test_post_deposit_then_update_refused(
     )
 
     assert r.status_code == status.HTTP_400_BAD_REQUEST
+    assert b"You can only act on deposit with status &#39;partial&#39;" in r.content
